import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import { sleepData } from './useData';
import { scaleBand, scaleLinear, min, max } from 'd3';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';
import { CircleMarks } from './CircleMarks';
import { CircleMarks2 } from './CircleMarks2';

const width = window.innerWidth;
const height = window.innerHeight;
const margin = { top: 20, left: 90, bottom: 60, right: 10 };
const innerHeight = height - margin.top - margin.bottom;
const innerWidth = width - margin.left - margin.right;

const xValue = (d) => d['moonPhase'];
const y2Value = (d) => d['decHoursAsleep'];
const y3Value = (d) => d;
const x2Value = (d) => d;

const App = () => {
  const data = sleepData(innerHeight);
  if (!data) {
    return <pre> Loading . . . </pre>;
  }

  const xAxisLabel =
    'Phase of the Moon (1 is New, 15 is Full)';
  const xScale = scaleBand()
    .domain(data.map(xValue))
    .range([0, innerWidth]);

  const yAxisLabel =
    'Total Hours Asleep and Avg Hours (green)';

  const y2Scale = scaleLinear()
    .domain([3, max(data.map(y2Value))])
    .range([innerHeight - margin.bottom, margin.top]);

  const x2Scale = scaleLinear()
    .domain([1, 31])
    .range([0, innerWidth]);

  console.log(data)
  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left}, ${margin.top})`}
      >
        <AxisLeft
          yScale={y2Scale}
          innerWidth={innerWidth}
        />
        <text
          className="axis-label"
          textAnchor="middle"
          transform={`translate(${-margin.left / 2},${
            innerHeight / 2
          }) rotate(-90)`}
        >
          {yAxisLabel}
        </text>
        <AxisBottom
          xScale={xScale}
          innerHeight={innerHeight}
          innerWidth={innerWidth}
        />
        <text
          className="axis-label"
          textAnchor="middle"
          transform={`translate(${innerHeight}, ${
            innerHeight + 50
          })`}
        >
          {xAxisLabel}
        </text>
        <CircleMarks
          xScale={xScale}
          y2Scale={y2Scale}
          xValue={xValue}
          y2Value={y2Value}
          data={data}
        />
        <CircleMarks2
          x2Scale={x2Scale}
          y2Scale={y2Scale}
          x2Value={x2Value}
          y3Value={y3Value}
          data={data}
        />
      </g>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);

/*
const y2Value = (d) => d;

const y2Scale = scaleLinear()
    .domain([-6, max(data['average'].map(y2Value))])
    .range([innerHeight - margin.bottom, margin.top]);
<CircleMarks
          xScale={xScale}
          y2Scale={y2Scale}
          xValue={xValue}
          y2Value={y2Value}
          data={data}
        />
*/
