import { useState, useEffect } from 'react'

const jsonUrl = 'https://gist.githubusercontent.com/KMSkelton/7770ad345b8b8140e8385e5c593efb86/raw/39d279e108bbe092381028f4bb08b1ac51fc77c1/sleep-2020-08-22.json'

const fetchData = async(url) => {
  const response = await fetch(url)
  const data = await response.json()
  data.map(d => {
    const endHour = d.endTime.split("T")[1]
    const startHour = d.startTime.split("T")[1]
    d['endHour'] = +endHour.split(":")[0] + +(endHour.split(":")[1]/60).toFixed(4)
    d['startHour'] = +startHour.split(":")[0] + +(startHour.split(":")[1]/60).toFixed(4)
    d['decHoursAsleep'] = +(d['minutesAsleep']/60).toFixed(4)
    d['calendarDayNumberOfSleep'] = +d['dateOfSleep'].split("-")[2]
    d['calendarYearNumberOfSleep'] = +d['dateOfSleep'].split("-")[0]
    d['calendarMonthNumberOfSleep'] = +d['dateOfSleep'].split("-")[1]
    d['moonPhase'] = Simple(d['calendarYearNumberOfSleep'], d['calendarMonthNumberOfSleep'], d['calendarDayNumberOfSleep'])
  })
  return data
}

function Simple(year,month,day)
{
	var lp = 2551443; 
	var now = new Date(year,month-1,day,20,35,0);						
	var new_moon = new Date(1970, 0, 7, 20, 35, 0);
	var phase = ((now.getTime() - new_moon.getTime())/1000) % lp;
	return Math.floor(phase /(24*3600)) + 1;
}

function takeAverage(data) {
  let phase = 1
  let total = 0
  let count = 0
  data['average'] = []
  for (let i = 0; i < data.length; i++) {
   if (phase === data[i]['moonPhase']) {
   	total += data[i]['decHoursAsleep']
    count ++
   } else {
   	data['average'][phase] = +(total / count).toFixed(4)
   	total = data[i]['decHoursAsleep']
    count = 1
    phase ++
   }
  }
	data['average'][phase] = +(total / count).toFixed(4)  // this covers the case for the last moon phase (30)
  return data
}

function removeErrantValues(data) {
  data = data.filter(d => d['endHour'] < 11 && d['endHour'] > 4)
  return data
}

function unifyDays(data) {
  data.sort((a,b) => (a.dateOfSleep > b.dateOfSleep) ? 1 : -1)
  for (let i = 0; i < data.length; i++) {
    if(data[i] && data[i+1] && data[i].endTime === data[i+1].endTime){
    	data.splice(data[i+1].endTime, 1)
    }
  }
  return data
}

function dataSort(data) {
 	data.sort((a,b) => (a.moonPhase > b.moonPhase) ? 1 : -1) 
  return data
}

export const sleepData = () => {
  const [data, setData] = useState() 
	
    useEffect(() => {
  	fetchData(jsonUrl)
      .then(data => removeErrantValues(data))
      .then(data => unifyDays(data))
      .then(data => dataSort(data))
      .then(data => takeAverage(data))     
      .then(data => setData(data))
  }, [])
  return data
}

